@@ -1,4 +1,4 @@
-# Copyright (C) 2019  The Software Heritage developers
+# Copyright (C) 2019-2020  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -10,15 +10,16 @@ import yaml
 from typing import Any, Dict
 
 from swh.scheduler.tests.conftest import swh_app  # noqa
+from swh.storage.tests.conftest import *  # noqa
 
 
 @pytest.fixture
-def swh_loader_config() -> Dict[str, Any]:
+def swh_loader_config(swh_storage_backend_config) -> Dict[str, Any]:
+    swh_storage_backend_config["journal_writer"] = {}
     return {
         "storage": {
             "cls": "pipeline",
             "steps": [
-                {"cls": "validate"},
                 {"cls": "filter"},
                 {
                     "cls": "buffer",
@@ -30,7 +31,7 @@ def swh_loader_config() -> Dict[str, Any]:
                         "release": 100,
                     },
                 },
-                {"cls": "memory"},
+                swh_storage_backend_config,
             ],
         },
         "check_revision": {"limit": 100, "status": False},
